# pyrbo
Python JIT compiler for near-native performance of low-level arithmetic

## Install
These are generic installation instructions.

### To use, permanently
The quickest way to get started is to install the current release from PyPI:
```
pip3 install --user pyrbo
```

### To use, temporarily
If you prefer to keep .local clean, install to a virtualenv:
```
python3 -m venv venvname
venvname/bin/pip install pyrbo
. venvname/bin/activate
```
